@@ -5,7 +5,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: albums.py 4330 2008-09-14 03:19:26Z piman $
+# $Id: albums.py 7fb5bf908e15 2009/06/22 01:57:25 $
 
 import os
 
@@ -575,10 +575,11 @@ class AlbumList(Browser, gtk.VBox, util.InstanceTracker):
         model, rows = selection.get_selected_rows()
         albums = [model[row][0] for row in rows]
         if None in albums:
-            albums = [model[row][0] for row in model]
+            albums = [row[0] for row in model]
         for album in albums:
-            album.cover = type(album).cover
-            album.finalize()
+            if album:
+                album.cover = type(album).cover
+                album.finalize()
 
     def __get_selected_albums(self, selection):
         if not selection:
@@ -687,6 +688,10 @@ class AlbumList(Browser, gtk.VBox, util.InstanceTracker):
         for row in model:
             if row[0] is not None and row[0].key == album_key:
                 view.scroll_to_cell(row.path[0], use_align=True, row_align=0.5)
+                sel = view.get_selection()
+                if row.path not in sel.get_selected_rows()[1]:
+                    sel.unselect_all()
+                    sel.select_path(row.path[0])
                 break
 
     def __selection_changed(self, selection, sort):
