@@ -5,7 +5,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: paned.py 4330 2008-09-14 03:19:26Z piman $
+# $Id: paned.py 7fb5bf908e15 2009/06/22 01:57:25 $
 
 import gobject
 import gtk
@@ -39,7 +39,7 @@ class Preferences(qltk.Window):
         pa = gtk.RadioButton(gpa, "_" + tag("~~people~album"))
         pa.headers = ["~people", "album"]
         custom = gtk.RadioButton(gpa, _("_Custom"))
-        custom.headers = []
+        custom.headers = config.get("browsers", "panes").split()
 
         align = gtk.Alignment()
         align.set_padding(0, 0, 12, 0)
@@ -81,8 +81,10 @@ class Preferences(qltk.Window):
         add = gtk.Button(stock=gtk.STOCK_ADD)
         add.connect('clicked', self.__add, model, cb)
         remove = gtk.Button(stock=gtk.STOCK_REMOVE)
-        remove.connect('clicked', self.__remove, view.get_selection())
-        view.get_selection().connect('changed', self.__changed, remove)
+
+        self.selection = view.get_selection()
+        remove.connect('clicked', self.__remove, self.selection)
+        self.selection.connect('changed', self.__changed, remove)
         vb_2.pack_start(add, expand=False)
         vb_2.pack_start(remove, expand=False)
         align.child.pack_start(vb_2, expand=False, fill=False)
@@ -134,7 +136,7 @@ class Preferences(qltk.Window):
             model.clear()
             for h in button.headers:
                 model.append(row=[h])
-        align.set_sensitive(not bool(button.headers))
+        align.set_sensitive(button.get_label() == _("_Custom"))
 
 class PanedBrowser(gtk.VBox, Browser, util.InstanceTracker):
     __gsignals__ = Browser.__gsignals__
@@ -293,6 +295,9 @@ class PanedBrowser(gtk.VBox, Browser, util.InstanceTracker):
                 if row[0] in values:
                     self.scroll_to_cell(
                         row.path[0], use_align=True, row_align=0.5)
+                    sel = self.get_selection()
+                    sel.unselect_all()
+                    sel.select_path(row.path[0])
                     break
 
         def get_selected(self):
