@@ -5,7 +5,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: playlists.py 4330 2008-09-14 03:19:26Z piman $
+# $Id: playlists.py 0cdf8a58f51e 2009/07/02 06:46:07 $
 
 import os
 import urllib
@@ -446,20 +446,21 @@ class Playlists(gtk.VBox, Browser):
                 return
             name = name or os.path.basename(uri) or _("New Playlist")
             uri = uri.encode('utf-8')
-            sock = urllib.urlopen(uri)
-            f = NamedTemporaryFile()
-            f.write(sock.read()); f.flush()
-            if uri.lower().endswith('.pls'):
-                playlist = ParsePLS(f.name, library=library)
-            elif uri.lower().endswith('.m3u'):
-                playlist = ParseM3U(f.name, library=library)
-            else: playlist = None
-            if playlist:
+            try:
+                sock = urllib.urlopen(uri)
+                f = NamedTemporaryFile()
+                f.write(sock.read()); f.flush()
+                if uri.lower().endswith('.pls'):
+                    playlist = ParsePLS(f.name, library=library)
+                elif uri.lower().endswith('.m3u'):
+                    playlist = ParseM3U(f.name, library=library)
+                else:
+                    raise IOError
                 library.add_filename(playlist)
                 if name: playlist.rename(name)
                 Playlists.changed(playlist)
                 ctx.finish(True, False, etime)
-            else:
+            except IOError:
                 ctx.finish(False, False, etime)
                 qltk.ErrorMessage(
                     qltk.get_top_parent(self),
@@ -479,6 +480,7 @@ class Playlists(gtk.VBox, Browser):
         if iter is None:
             return
         songs = list(model[iter][0])
+        songs = filter(lambda s: isinstance(s, AudioFile), songs)
         menu = SongsMenu(library, songs, playlists=False, remove=False)
         menu.preseparate()
 
@@ -529,7 +531,7 @@ class Playlists(gtk.VBox, Browser):
 
     def __import(self, activator, library):
         filt = lambda fn: fn.endswith(".pls") or fn.endswith(".m3u")
-        from qltk.chooser import FileChooser
+        from quodlibet.qltk.chooser import FileChooser
         chooser = FileChooser(self, _("Import Playlist"), filt, const.HOME)
         files = chooser.run()
         chooser.destroy()
@@ -560,12 +562,14 @@ class Playlists(gtk.VBox, Browser):
     def reordered(self, songlist):
         songs = songlist.get_songs()
         model, iter = self.__view.get_selection().get_selected()
+        playlist = None
         if iter:
             playlist = model[iter][0]
             playlist[:] = songs
-        else:
+        elif songs:
             playlist = Playlist.fromsongs(songs)
             gobject.idle_add(self.__select_playlist, playlist)
-        Playlists.changed(playlist, refresh=False)
+        if playlist:
+            Playlists.changed(playlist, refresh=False)
 
 browsers = [Playlists]
