@@ -4,7 +4,7 @@
 import os
 import locale
 
-VERSION_TUPLE = (2, 0)
+VERSION_TUPLE = (2, 1)
 VERSION = ".".join(map(str, VERSION_TUPLE))
 
 HOME    = os.path.expanduser("~")
@@ -54,6 +54,8 @@ Remi Vanicat
 Ari Pollak
 Jan Arne Petersen
 Josh Lee
+Steven Robertson
+Christoph Reiter
 """.strip().split("\n"))
 
 ARTISTS = sorted("""\
