@@ -5,7 +5,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: __init__.py 4330 2008-09-14 03:19:26Z piman $
+# $Id: __init__.py 3009a77e2166 2009/06/28 05:02:42 $
 
 import os
 import traceback
@@ -82,6 +82,13 @@ def get_by_udi(udi):
     except dbus.DBusException:
         return None
 
+    try:
+        media = interface.GetProperty('storage.removable.media_available')
+        if not media:
+            return None
+    except dbus.DBusException:
+        pass
+
     if 'portable_audio_player' in capabilities:
         try:
             protocols = interface.GetProperty(
