@@ -4,7 +4,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: _audio.py 4330 2008-09-14 03:19:26Z piman $
+# $Id: _audio.py bce688b08470 2009/06/22 01:58:49 $
 
 # Much of this code is highly optimized, because many of the functions
 # are called in tight loops. Don't change things just to make them
@@ -22,6 +22,7 @@ from quodlibet.util.uri import URI
 
 from quodlibet.util.tags import STANDARD_TAGS as USEFUL_TAGS
 from quodlibet.util.tags import MACHINE_TAGS
+from quodlibet.util.titlecase import title
 
 MIGRATE = ("~#playcount ~#laststarted ~#lastplayed ~#added "
            "~#skipcount ~#rating ~bookmark").split()
@@ -151,16 +152,31 @@ class AudioFile(dict):
                 return (join([person for (i, person) in enumerate(people)
                               if index(person) == i]) or
                         self("~people", default, connector))
-            elif key == "performers":
-                values = []
+            elif key == "performers" or key == "performer":
+                performers = {}
                 for key in self.realkeys():
                     if key.startswith("performer:"):
                         role = key.split(":", 1)[1]
                         for value in self.list(key):
-                            values.append("%s (%s)" % (value, role))
+                            try:
+                                performers[str(value)]
+                            except:
+                                performers[str(value)] = []
+                            performers[str(value)].append(util.title(role))
+                values = []
+                if len(performers) > 0:
+                    for performer in performers:
+                        roles = ''
+                        i = 0
+                        for role in performers[performer]:
+                            if i > 0:
+                                roles += ', '                            
+                            roles += role
+                            i += 1
+                        values.append("%s (%s)" % (performer, roles))
                 values.extend(self.list("performer"))
                 return "\n".join(values)
-            elif key == "performerssort":
+            elif key == "performerssort" or key == "performersort":
                 values = []
                 for key in self.realkeys():
                     if key.startswith("performersort:"):
@@ -274,6 +290,7 @@ class AudioFile(dict):
             if os.access(self["~filename"], os.W_OK): return True
             else: return []
         else: return (k and "=" not in k and "~" not in k
+                      and k.encode("ascii", "replace") == k
                       and os.access(self["~filename"], os.W_OK))
 
     def rename(self, newname):
@@ -314,7 +331,12 @@ class AudioFile(dict):
 
     def sanitize(self, filename=None):
         """Fill in metadata defaults. Find ~mountpoint, ~#mtime,
-        and ~#added."""
+        and ~#added. Check for null bytes in tags."""
+
+        # Replace nulls with newlines, trimming zero-length segments
+        for key, val in self.items():
+            if isinstance(val, basestring) and '\0' in val:
+                self[key] = '\n'.join(filter(lambda s: s, val.split('\0')))
 
         if filename: self["~filename"] = filename
         elif "~filename" not in self: raise ValueError("Unknown filename!")
