@@ -5,7 +5,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: filesel.py 4330 2008-09-14 03:19:26Z piman $
+# $Id: filesel.py ffb94ed0ec0b 2009/06/22 02:15:48 $
 
 import os
 import urlparse
@@ -226,6 +226,8 @@ class DirectoryTree(RCMTreeView, MultiDragTreeView):
                     pass
             if not model.iter_has_child(iter):
                 return True
+        except OSError:
+            pass
         finally:
             if window:
                 window.set_cursor(None)
