@@ -5,7 +5,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: quodlibetwindow.py 4330 2008-09-14 03:19:26Z piman $
+# $Id: quodlibetwindow.py 68c09168ec2f 2009/06/28 06:32:57 $
 
 import os
 import random
@@ -363,6 +363,9 @@ class QuodLibetWindow(gtk.Window):
         if self.__hidden_state & gtk.gdk.WINDOW_STATE_MAXIMIZED:
             self.maximize()
 
+    def destroy(self, *args):
+        super(QuodLibetWindow, self).destroy()
+
     def __show_or(self, widget, prop):
         ssv = self.song_scroller.get_property('visible')
         qxv = self.qexpander.get_property('visible')
@@ -389,7 +392,7 @@ class QuodLibetWindow(gtk.Window):
              self.__preferences),
             ("Plugins", stock.PLUGINS, None, None, None,
              self.__plugins),
-            ("Quit", gtk.STOCK_QUIT, None, None, None, gtk.main_quit),
+            ("Quit", gtk.STOCK_QUIT, None, None, None, self.destroy),
             ('Filters', None, _("_Filters")),
 
             ("NotPlayedDay", gtk.STOCK_FIND, _("Not Played To_day"),
@@ -641,7 +644,8 @@ class QuodLibetWindow(gtk.Window):
 
     def __jump_to_current(self, explicit):
         if player.playlist.song is None: return
-        elif player.playlist.song == self.songlist.model.current:
+        if explicit: self.browser.scroll(player.playlist.song)
+        if player.playlist.song == self.songlist.model.current:
             path = self.songlist.model.current_path
             self.songlist.scroll_to_cell(
                 path[0], use_align=True, row_align=0.5)
@@ -650,7 +654,6 @@ class QuodLibetWindow(gtk.Window):
                 selection = self.songlist.get_selection()
                 selection.unselect_all()
                 selection.select_path(path)
-        if explicit: self.browser.scroll(player.playlist.song)
 
     def __next_song(self, *args): player.playlist.next()
     def __previous_song(self, *args): player.playlist.previous()
