@@ -4,7 +4,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: songlist.py 4330 2008-09-14 03:19:26Z piman $
+# $Id: songlist.py d142391b7a3f 2009/06/18 23:15:26 $
 
 import datetime
 import time
@@ -566,6 +566,7 @@ class SongList(AllTreeView, util.InstanceTracker):
         x, y = map(int, [event.x, event.y])
         try: path, col, cellx, celly = view.get_path_at_pos(x, y)
         except TypeError: return True
+        if event.window != self.get_bin_window(): return False
         if col.header_name == "~#rating":
             song = view.get_model()[path][0]
             l = gtk.Label()
@@ -815,7 +816,7 @@ class SongList(AllTreeView, util.InstanceTracker):
             menu.append(item)
             submenu = gtk.Menu()
             item.set_submenu(submenu)
-            for header in sorted(zip(map(tag, group), group)):
+            for header in sorted(zip(map(util.tag, group), group)):
                 add_header_toggle(submenu, header, header[1] in current_set)
 
         sep = gtk.SeparatorMenuItem()
