@@ -4,7 +4,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 #
-# $Id: uri.py 4330 2008-09-14 03:19:26Z piman $
+# $Id: uri.py 6919aa22828d 2009/06/22 04:53:02 $
 
 # TODO:
 #  * netloc separation (user/passwd/host/port using urllib)
@@ -46,7 +46,8 @@ class URI(str):
             values[2] = quote_plus(values[2], safe="/~")
         value = urlunparse(values)
         obj = str.__new__(klass, value)
-        if not obj.scheme: raise ValueError("URIs must have a scheme")
+        if not obj.scheme:
+            raise ValueError("URIs must have a scheme, such as 'http://'")
         elif not (obj.netloc or obj.path):
             raise ValueError("URIs must have a network location or path")
         else: return obj
