@@ -1,8 +1,8 @@
-import gtk
 from tests import TestCase, add
-from qltk.sliderbutton import HSlider, VSlider
 
-class dummy(object): pass
+import gtk
+
+from quodlibet.qltk.sliderbutton import VSlider
 
 class TVSlider(TestCase):
     Kind = VSlider
