@@ -1,12 +1,22 @@
 from tests import TestCase, add
-from qltk.songlist import PlaylistModel, PlaylistMux, SongList
+
 import gtk
-from qltk.watcher import SongWatcher
+
+from quodlibet.player.nullbe import NullPlayer
+from quodlibet.library import SongLibrary
+from quodlibet.qltk.songlist import PlaylistModel, PlaylistMux, SongList
+from quodlibet.qltk.playorder import ORDERS
+import quodlibet.config
+
+def do_events():
+    while gtk.events_pending():
+        gtk.main_iteration()
 
 class TPlaylistModel(TestCase):
     def setUp(self):
         self.pl = PlaylistModel()
         self.pl.set(range(10))
+        do_events()
         self.failUnless(self.pl.current is None)
 
     def test_isempty(self):
@@ -17,6 +27,7 @@ class TPlaylistModel(TestCase):
     def test_get(self):
         self.assertEqual(self.pl.get(), range(10))
         self.pl.set(range(12))
+        gtk.main_iteration(False)
         self.assertEqual(self.pl.get(), range(12))
 
     def test_next(self):
@@ -80,7 +91,7 @@ class TPlaylistModel(TestCase):
         self.assertEqual(self.pl.current, 4)
 
     def test_shuffle(self):
-        self.pl.order = 1
+        self.pl.order = ORDERS[1](self.pl)
         for i in range(5):
             numbers = [self.pl.current for i in range(10)
                        if self.pl.next() or True]
@@ -91,12 +102,13 @@ class TPlaylistModel(TestCase):
             self.assertEqual(self.pl.current, None)
 
     def test_weighted(self):
-        self.pl.order = 2
+        self.pl.order = ORDERS[2](self.pl)
         r0 = {'~#rating': 0}
         r1 = {'~#rating': 1}
         r2 = {'~#rating': 2}
         r3 = {'~#rating': 3}
         self.pl.set([r0, r1, r2, r3])
+        gtk.main_iteration(False)
         songs = [self.pl.current for i in range(1000)
                  if self.pl.next() or True]
         self.assert_(songs.count(r1) > songs.count(r0))
@@ -104,7 +116,7 @@ class TPlaylistModel(TestCase):
         self.assert_(songs.count(r3) > songs.count(r2))
 
     def test_shuffle_repeat(self):
-        self.pl.order = 1
+        self.pl.order = ORDERS[1](self.pl)
         self.pl.repeat = True
         numbers = [self.pl.current for i in range(30)
                    if self.pl.next() or True]
@@ -116,7 +128,7 @@ class TPlaylistModel(TestCase):
 
     def test_onesong(self):
         self.pl.go_to(3)
-        self.pl.order = 3
+        self.pl.order = ORDERS[3](self.pl)
         self.failUnlessEqual(self.pl.current, 3)
         self.pl.next()
         self.failUnlessEqual(self.pl.current, 4)
@@ -125,7 +137,7 @@ class TPlaylistModel(TestCase):
 
     def test_onesong_repeat(self):
         self.pl.go_to(3)
-        self.pl.order = 3
+        self.pl.order = ORDERS[3](self.pl)
         self.pl.repeat = True
         self.failUnlessEqual(self.pl.current, 3)
         self.pl.next()
@@ -147,11 +159,12 @@ class TPlaylistModel(TestCase):
         self.pl.go_to(5)
         self.failUnlessEqual(self.pl.current, 5)
         self.pl.set([5, 10, 15, 20])
+        gtk.main_iteration(False)
         self.pl.next()
         self.failUnlessEqual(self.pl.current, 10)
 
     def test_go_to_order(self):
-        self.pl.order = 1
+        self.pl.order = ORDERS[1](self.pl)
         for i in range(5):
             self.pl.go_to(5)
             self.failUnlessEqual(self.pl.current, 5)
@@ -174,7 +187,7 @@ class TPlaylistModel(TestCase):
         self.failUnlessEqual(self.pl.current, 0)
 
     def test_reset_order(self):
-        self.pl.order = 1
+        self.pl.order = ORDERS[1](self.pl)
         self.pl.go_to(5)
         self.failUnlessEqual(self.pl.current, 5)
         self.pl.reset()
@@ -183,30 +196,33 @@ class TPlaylistModel(TestCase):
     def test_restart(self):
         self.pl.go_to(1)
         self.pl.set([101, 102, 103, 104])
+        gtk.main_iteration(False)
         self.pl.next()
         self.failUnlessEqual(self.pl.current, 101)
 
     def test_next_nosong_536(self):
         self.pl.go_to(1)
         self.pl.repeat = True
-        self.pl.order = 1
+        self.pl.order = ORDERS[1](self.pl)
         self.pl.set([])
+        gtk.main_iteration(False)
         self.pl.next()
 
     def shutDown(self):
         self.pl.destroy()
 add(TPlaylistModel)
 
-class Mux(TestCase):
+class TPlaylistMux(TestCase):
     def setUp(self):
         self.q = PlaylistModel()
         self.pl = PlaylistModel()
-        self.w = SongWatcher()
-        self.mux = PlaylistMux(self.w, self.q, self.pl)
+        self.p = NullPlayer()
+        self.mux = PlaylistMux(self.p, self.q, self.pl)
         self.failUnless(self.pl.current is None)
 
     def test_only_pl(self):
         self.pl.set(range(10))
+        do_events()
         self.failUnless(self.mux.current is None)
         songs = [self.next() for i in range(10)]
         self.failUnlessEqual(songs, range(10))
@@ -215,6 +231,7 @@ class Mux(TestCase):
 
     def test_only_q(self):
         self.q.set(range(10))
+        do_events()
         self.failUnless(self.mux.current is None)
         songs = [self.next() for i in range(10)]
         self.failUnlessEqual(songs, range(10))
@@ -224,6 +241,7 @@ class Mux(TestCase):
     def test_mixed(self):
         self.q.set(range(5))
         self.pl.set(range(5, 10))
+        do_events()
         self.failUnless(self.mux.current is None)
         songs = [self.next() for i in range(10)]
         self.failUnlessEqual(songs, range(10))
@@ -232,22 +250,28 @@ class Mux(TestCase):
 
     def test_newplaylist(self):
         self.pl.set(range(5, 10))
+        do_events()
         self.failUnless(self.mux.current is None)
         self.mux.go_to(7)
         self.failUnlessEqual(self.mux.current, 7)
         self.pl.set([3, 5, 12, 11])
+        do_events()
         self.failUnlessEqual(self.mux.current, None)
         self.pl.set([19, 8, 12, 3])
+        do_events()
         self.failUnlessEqual(self.mux.current, None)
         self.pl.set([3, 7, 9, 11])
+        do_events()
         self.mux.next()
         self.failUnlessEqual(self.mux.current, 9)
 
     def test_halfway(self):
         self.pl.set(range(10))
+        do_events()
         self.failUnless(self.mux.current is None)
         songs = [self.next() for i in range(5)]
         self.q.set(range(100, 105))
+        do_events()
         songs.extend([self.next() for i in range(10)])
         self.failUnlessEqual(
             songs, [0, 1, 2, 3, 4, 100, 101, 102, 103, 104, 5, 6, 7, 8, 9])
@@ -257,6 +281,7 @@ class Mux(TestCase):
     def test_removal(self):
         self.pl.set(range(0, 5))
         self.q.set(range(10, 15))
+        do_events()
         songs = [self.next() for i in range(3)]
         self.q.remove(self.q.find(14))
         self.q.remove(self.q.find(13))
@@ -266,13 +291,14 @@ class Mux(TestCase):
     def next(self):
         self.mux.next()
         song = self.mux.current
-        self.w.song_started(self.mux.current)
-        while gtk.events_pending(): gtk.main_iteration()
+        self.p.emit('song-started', self.mux.current)
+        do_events()
         return song
 
     def test_goto(self):
         self.pl.set(range(10))
         self.q.set(range(10, 20))
+        do_events()
         self.failUnless(self.mux.current is None)
         self.mux.go_to(5)
         self.failUnlessEqual(self.mux.current, 5)
@@ -283,15 +309,33 @@ class Mux(TestCase):
         self.failUnlessEqual(self.mux.current, 7)
         self.failUnlessEqual(self.next(), 11)
 
+    def test_random_queue_666(self):
+        for i in range(5):
+            self.mux.go_to(None)
+            self.pl.set([1])
+            do_events()
+            self.failUnless(self.mux.current is None)
+            self.q.order = ORDERS[1](self.pl)
+            self.failUnless(self.next() == 1)
+            self.q.set([10, 11])
+            do_events()
+            value = self.next()
+            self.failUnless(
+                value in [10, 11], "got %r, expected 10 or 11" % value)
+            if value == 10: next = 11
+            else: next = 10
+            self.failUnlessEqual(self.next(), next)
+
     def tearDown(self):
-        self.w.destroy()
-add(Mux)
+        self.p.destroy()
+add(TPlaylistMux)
 
 class TSongList(TestCase):
     HEADERS = ["acolumn", "~#lastplayed", "~foo~bar", "~#rating",
                "~#length", "~dirname", "~#track"]
     def setUp(self):
-        self.songlist = SongList(SongWatcher())
+        quodlibet.config.init()
+        self.songlist = SongList(SongLibrary())
 
     def test_set_all_column_headers(self):
         SongList.set_all_column_headers(self.HEADERS)
@@ -319,4 +363,5 @@ class TSongList(TestCase):
 
     def tearDown(self):
         self.songlist.destroy()
+        quodlibet.config.quit()
 add(TSongList)
